![](https://github.com/mariuzka/pop2net/actions/workflows/tox.yml/badge.svg)
![Python 3.9+](https://img.shields.io/badge/python->=3.9-blue.svg)

# Pop2net

Pop2net is a Python package designed to generate and manage relations between agents in agent-based models in a simple and flexible way.

# Documentation
Detailed documentation of all features and a collection of example analyses can be found [here](https://mariuzka.github.io/pop2net/).
